### Download pre-trained weights
You can download the weights from
* [Google Drive](https://drive.google.com/drive/folders/10UPPx6V13oQW6knuLV7d8SRIA3D6hYor?usp=drive_link)
* [Tencent Weiyun](https://share.weiyun.com/J1BWWkQF)

and save model weights to this dir
```bash
cd DNAGPT
mkdir checkpoints
# download or copy model weight to this default directory
```
#### Foundation model
* [dna_gpt0.1b_h.pth](https://drive.google.com/file/d/15m6CH3zaMSqflOaf6ec5VPfiulg-Gh0u/view?usp=drive_link): DNAGPT 0.1B params model pretrained with human genomes
* [dna_gpt0.1b_m.pth](https://drive.google.com/file/d/1C0BRXfz7RNtCSjSY1dKQeR1yP7I3wTyx/view?usp=drive_link): DNAGPT 0.1B params model pretrained with mutli-organism genomes
* [dna_gpt3b_m.pth](https://drive.google.com/file/d/1pQ3Ai7C-ObzKkKTRwuf6eshVneKHzYEg/view?usp=drive_link): DNAGPT 3B params model pretrained with mutli-organism genomes
